@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Any, Type, override, Iterable, Literal, TYPE_CHECKING
+from typing import Any, Type, override, Iterable, Literal, TYPE_CHECKING, Optional
 from collections import defaultdict
 import abc
 
@@ -16,14 +16,16 @@ if TYPE_CHECKING:
 ORDER_QUERIES = Literal["select", "join", "where", "order", "with", "group by", "limit", "offset"]
 
 
-class AbstractSQLStatements[T: Table, TRepo](IStatements_two_generic[T, TRepo]):
+class AbstractSQLStatements[T: Table, *Ts, TRepo](IStatements_two_generic[T, *Ts, TRepo]):
     __slots__ = ("_model", "_repository", "_query_list")
     __order__: tuple[str, ...] = ("select", "join", "where", "order", "with", "group by", "limit", "offset")
 
-    def __init__(self, model: T, repository: IRepositoryBase[TRepo]) -> None:
+    def __init__(self, model: tuple[T, *Ts], repository: IRepositoryBase[TRepo]) -> None:
         self.__valid_repository(repository)
 
-        self._model: T = model
+        self._query: Optional[str] = None
+        self._model: T = model[0] if isinstance(model, Iterable) else model
+        self._models: tuple[T, *Ts] = self._model if isinstance(model, Iterable) else (model,)
         self._repository: IRepositoryBase[TRepo] = repository
         self._query_list: dict[ORDER_QUERIES, list[IQuery]] = defaultdict(list)
 
@@ -41,12 +43,8 @@ class AbstractSQLStatements[T: Table, TRepo](IStatements_two_generic[T, TRepo]):
     def __repr__(self):
         return f"<Model: {self.__class__.__name__}>"
 
-    @property
-    @override
-    def repository(self) -> IRepositoryBase[TRepo]: ...
-
-    def _return_flavour[TValue](self, query, flavour: Type[TValue], select) -> tuple[TValue]:
-        return self._repository.read_sql(query, flavour=flavour, model=self._model, select=select)
+    def _return_flavour[TValue](self, query, flavour: Type[TValue], select, **kwargs) -> tuple[TValue]:
+        return self._repository.read_sql(query, flavour=flavour, model=self._model, select=select, **kwargs)
 
     def _return_model(self, select, query: str):
         response_sql = self._repository.read_sql(query, flavour=dict, model=self._model, select=select)  # store all columns of the SQL query
@@ -59,6 +57,22 @@ class AbstractSQLStatements[T: Table, TRepo](IStatements_two_generic[T, TRepo]):
     @abc.abstractmethod
     def _build(sef): ...
 
+    @property
+    def query(self) -> str:
+        return self._query
+
+    @property
+    def model(self) -> Type[T]:
+        return self._model
+
+    @property
+    def models(self) -> tuple[*Ts]:
+        return self._models
+
+    @property
+    @override
+    def repository(self) -> IRepositoryBase[TRepo]: ...
+
 
 class ClusterQuery[T]:
     def __init__(self, select: DecompositionQueryBase[T], response_sql: tuple[dict[str, Any]]) -> None:
@@ -82,7 +96,7 @@ class ClusterQuery[T]:
             for dicc_cols in self._response_sql:
                 valid_attr: dict[str, Any] = {}
                 for clause in clauses:
-                    if not hasattr(table, clause.column):
+                    if clause.column is None or not hasattr(table, clause.column):
                         agg_methods = self.__get_all_aggregate_method(clauses)
                         raise ValueError(f"You cannot use aggregation method like '{agg_methods}' to return model objects. Try specifying 'flavour' attribute as 'dict'.")
                     valid_attr[clause.column] = dicc_cols[clause.alias]
