@@ -12,11 +12,15 @@ if tp.TYPE_CHECKING:
 from .IQueryCommand import IQuery
 
 
-class IDecompositionQuery[T: tp.Type[Table]](IQuery):
+class IDecompositionQuery[T: tp.Type[Table], *Ts](IQuery):
     @property
     @abc.abstractmethod
     def table(self) -> T: ...
 
+    @property
+    @abc.abstractmethod
+    def tables(self) -> tuple[*Ts]: ...
+
     @property
     @abc.abstractmethod
     def lambda_query[*Ts](self) -> tp.Callable[[T], tuple[*Ts]]: ...
@@ -31,7 +35,7 @@ class IDecompositionQuery[T: tp.Type[Table]](IQuery):
 
     @property
     @abc.abstractmethod
-    def fk_relationship(self) -> tuple[tuple[tp.Type[Table], tp.Type[Table]]]: ...
+    def fk_relationship(self) -> set[tuple[tp.Type[Table], tp.Type[Table]]]: ...
 
     @property
     @abc.abstractmethod
