@@ -9,7 +9,7 @@ class IRepositoryBase[T](ABC):
         return f"{IRepositoryBase.__name__}: {self.__class__.__name__}"
 
     @abstractmethod
-    def read_sql[TFlavour](self, query: str, flavour: Optional[Type[TFlavour]], **kwargs) -> tuple[TFlavour]: ...
+    def read_sql[TFlavour](self, cnx: T, query: str, flavour: Optional[Type[TFlavour]], **kwargs) -> tuple[TFlavour]: ...
 
     @abstractmethod
     def executemany_with_values(self, query: str, values) -> None: ...
@@ -35,10 +35,6 @@ class IRepositoryBase[T](ABC):
     @abstractmethod
     def database_exists(self, name: str) -> bool: ...
 
-    @property
-    @abstractmethod
-    def connection(self) -> T: ...
-
     @property
     @abstractmethod
     def database(self) -> Optional[str]: ...
