@@ -35,7 +35,7 @@ type SelectRes10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10] = tuple[*SelectRes9[T1
 
 
 type WhereCondition[T, T1] = Callable[[T, T1], bool]
-type JoinCondition[T, T1] = tuple[T1, WhereCondition[T, T1]]
+type JoinCondition[T, T1] = tuple[T1, WhereCondition[T, T1], Optional[JoinType]]
 
 type TupleJoins1[T, T1] = tuple[JoinCondition[T, T1]]
 type TupleJoins2[T, T1, T2] = tuple[*TupleJoins1[T, T1], JoinCondition[T, T2]]
@@ -227,22 +227,29 @@ class IStatements[T, *Ts](ABC):
     # region join
 
     @overload
-    def join[T1](self, joins: JoinCondition[T, T1]) -> IStatements[T, T1]: ...
+    def join[T1](self, table: T1, relation: WhereCondition[T, T1], join_type: Optional[JoinType]) -> IStatements[T, T1]: ...
     @overload
-    def join[T1](self, joins: TupleJoins1[T, T1]) -> IStatements[T, T1]: ...
+    def join[T1](self, table: JoinCondition[T, T1]) -> IStatements[T, T1]: ...
     @overload
-    def join[T1, T2](self, joins: TupleJoins2[T, T1, T2]) -> IStatements[T, T1, T2]: ...
+    def join[T1](self, table: TupleJoins1[T, T1]) -> IStatements[T, T1]: ...
     @overload
-    def join[T1, T2, T3](self, joins: TupleJoins3[T, T1, T2, T3]) -> IStatements[T, T1, T2, T3]: ...
+    def join[T1, T2](self, table: TupleJoins2[T, T1, T2]) -> IStatements[T, T1, T2]: ...
     @overload
-    def join[T1, T2, T3, T4](self, joins: TupleJoins4[T, T1, T2, T3, T4]) -> IStatements[T, T1, T2, T3, T4]: ...
+    def join[T1, T2, T3](self, table: TupleJoins3[T, T1, T2, T3]) -> IStatements[T, T1, T2, T3]: ...
     @overload
-    def join[T1, T2, T3, T4, T5](self, joins: TupleJoins5[T, T1, T2, T3, T4, T5]) -> IStatements[T, T1, T2, T3, T4, T5]: ...
+    def join[T1, T2, T3, T4](self, table: TupleJoins4[T, T1, T2, T3, T4]) -> IStatements[T, T1, T2, T3, T4]: ...
     @overload
-    def join[T1, T2, T3, T4, T5, T6](self, joins: TupleJoins6[T, T1, T2, T3, T4, T5, T6]) -> IStatements[T, T1, T2, T3, T4, T5, T6]: ...
+    def join[T1, T2, T3, T4, T5](self, table: TupleJoins5[T, T1, T2, T3, T4, T5]) -> IStatements[T, T1, T2, T3, T4, T5]: ...
+    @overload
+    def join[T1, T2, T3, T4, T5, T6](self, table: TupleJoins6[T, T1, T2, T3, T4, T5, T6]) -> IStatements[T, T1, T2, T3, T4, T5, T6]: ...
 
     @abstractmethod
-    def join[*FKTables](self, joins) -> IStatements[T, *FKTables]: ...
+    def join[*FKTables](
+        self,
+        table: Optional[T] = ...,
+        relation: Optional[WhereCondition[T, FKTables]] = ...,
+        join_type: Optional[JoinType] = ...,
+    ) -> IStatements[T, *FKTables]: ...
 
     # endregion
     # region select
