@@ -1,7 +1,9 @@
 from __future__ import annotations
-from typing import override, Callable, overload, Optional, TYPE_CHECKING
+from collections import defaultdict
+from typing import override, Callable, overload, Optional, TYPE_CHECKING, Type
 
 
+from ormlambda.utils.module_tree.dfs_traversal import DFSTraversal
 from ormlambda.common.interfaces.IQueryCommand import IQuery
 from ormlambda import Disassembler
 from ormlambda import JoinType
@@ -21,6 +23,13 @@ class JoinSelector[TLeft, TRight](IQuery):
         "_compareop",
     )
 
+    @override
+    def __repr__(self) -> str:
+        table_col_left: str = f"{self._orig_table.__table_name__}.{self._left_col}"
+        table_col_right: str = f"{self._table_right.__table_name__}.{self._right_col}"
+
+        return f"{IQuery.__name__}: {self.__class__.__name__} ({table_col_left} == {table_col_right})"
+
     @overload
     def __init__(
         self,
@@ -102,3 +111,32 @@ class JoinSelector[TLeft, TRight](IQuery):
             right_col,  # second_col
         ]
         return " ".join(list_)
+
+    @classmethod
+    def sort_join_selectors(cls, joins: set[JoinSelector]) -> tuple[JoinSelector]:
+        # FIXME [x]: How to sort when needed because it's not necessary at this point. It is for testing purpouse
+        if len(joins) == 1:
+            return tuple(joins)
+
+        join_object_map: dict[str, list[JoinSelector]] = defaultdict(list)
+
+        for obj in joins:
+            join_object_map[obj._orig_table].append(obj)
+
+        graph: dict[Type[Table], list[Type[Table]]] = defaultdict(list)
+        for join in joins:
+            graph[join._orig_table].append(join._table_right)
+
+        sorted_graph = DFSTraversal.sort(graph)[::-1]
+
+        if not sorted_graph:
+            return tuple(joins)
+
+        res = []
+        for table in sorted_graph:
+            tables = join_object_map[table]
+
+            if not tables:
+                continue
+            res.extend(tables)
+        return res
