@@ -22,13 +22,14 @@ if TYPE_CHECKING:
     from ormlambda import Table
     from src.ormlambda.databases.my_sql.clauses.select import Select
 
+type TResponse[TFlavour, *Ts] = TFlavour | tuple[dict[str, tuple[*Ts]]] | tuple[tuple[*Ts]] | tuple[TFlavour]
+
 
 class Response[TFlavour, *Ts]:
-    def __init__(self, response_values: list[tuple[*Ts]], columns: tuple[str], flavour: Type[TFlavour], model: Optional[Table] = None, select: Optional[Select] = None, **kwargs) -> None:
+    def __init__(self, response_values: list[tuple[*Ts]], columns: tuple[str], flavour: Type[TFlavour], model: Optional[Table] = None, select: Optional[Select] = None) -> None:
         self._response_values: list[tuple[*Ts]] = response_values
         self._columns: tuple[str] = columns
         self._flavour: Type[TFlavour] = flavour
-        self._kwargs: dict[str, Any] = kwargs
         self._model: Table = model
         self._select: Select = select
 
@@ -47,23 +48,28 @@ class Response[TFlavour, *Ts]:
     def is_many(self) -> bool:
         return self._response_values_index > 1
 
-    @property
-    def response(self) -> tuple[dict[str, tuple[*Ts]]] | tuple[tuple[*Ts]] | tuple[TFlavour]:
+    def response(self, _tuple: bool, **kwargs) -> TResponse[TFlavour, *Ts]:
         if not self.is_there_response:
             return tuple([])
-        clean_response = self._response_values
-        if self._select is not None:
-            clean_response = self._parser_response()
-        return tuple(self._cast_to_flavour(clean_response))
+        cleaned_response = self._response_values
 
-    def _cast_to_flavour(self, data: list[tuple[*Ts]]) -> list[dict[str, tuple[*Ts]]] | list[tuple[*Ts]] | list[TFlavour]:
-        def _dict() -> list[dict[str, tuple[*Ts]]]:
+        if self._select is not None:
+            cleaned_response = self._parser_response()
+
+        cast_flavour = self._cast_to_flavour(cleaned_response, **kwargs)
+        if _tuple is not True:
+            return cast_flavour
+
+        return tuple(cast_flavour)
+
+    def _cast_to_flavour(self, data: list[tuple[*Ts]], **kwargs) -> list[dict[str, tuple[*Ts]]] | list[tuple[*Ts]] | list[TFlavour]:
+        def _dict(**kwargs) -> list[dict[str, tuple[*Ts]]]:
             return [dict(zip(self._columns, x)) for x in data]
 
-        def _tuple() -> list[tuple[*Ts]]:
+        def _tuple(**kwargs) -> list[tuple[*Ts]]:
             return data
 
-        def _set() -> list[set]:
+        def _set(**kwargs) -> list[set]:
             for d in data:
                 n = len(d)
                 for i in range(n):
@@ -73,16 +79,20 @@ class Response[TFlavour, *Ts]:
                         raise TypeError(f"unhashable type '{type(d[i])}' found in '{type(d)}' when attempting to cast the result into a '{set.__name__}' object")
             return [set(x) for x in data]
 
-        def _default() -> list[TFlavour]:
-            return [self._flavour(x, **self._kwargs) for x in data]
+        def _list(**kwargs) -> list[list]:
+            return [list(x) for x in data]
+
+        def _default(**kwargs) -> list[TFlavour]:
+            return self._flavour(data, **kwargs)
 
         selector: dict[Type[object], Any] = {
             dict: _dict,
             tuple: _tuple,
             set: _set,
+            list: _list,
         }
 
-        return selector.get(self._flavour, _default)()
+        return selector.get(self._flavour, _default)(**kwargs)
 
     def _parser_response(self) -> TFlavour:
         new_response: list[list] = []
@@ -123,8 +133,7 @@ class MySQLRepository(IRepositoryBase[MySQLConnection]):
         def wrapper(self: MySQLRepository, *args, **kwargs):
             with self._pool.get_connection() as cnx:
                 try:
-                    foo = func(self, cnx._cnx, *args, **kwargs)
-                    return foo
+                    return func(self, cnx._cnx, *args, **kwargs)
                 except Exception as e:
                     cnx._cnx.rollback()
                     raise e
@@ -140,7 +149,13 @@ class MySQLRepository(IRepositoryBase[MySQLConnection]):
 
     @override
     @get_connection
-    def read_sql[TFlavour](self, cnx: MySQLConnection, query: str, flavour: Type[TFlavour] = tuple, **kwargs) -> tuple[TFlavour]:
+    def read_sql[TFlavour](
+        self,
+        cnx: MySQLConnection,
+        query: str,
+        flavour: Type[TFlavour] = tuple,
+        **kwargs,
+    ) -> tuple[TFlavour]:
         """
         Return tuple of tuples by default.
 
@@ -150,19 +165,15 @@ class MySQLRepository(IRepositoryBase[MySQLConnection]):
             - flavour: Type[TFlavour]: Useful to return tuple of any Iterable type as dict,set,list...
         """
 
-        def get_and_drop_key(key: str) -> Optional[Any]:
-            if key in kwargs:
-                return kwargs.pop(key)
-            return None
-
-        model: Table = get_and_drop_key("model")
-        select: Select = get_and_drop_key("select")
+        model: Table = kwargs.pop("model", None)
+        select: Select = kwargs.pop("select", None)
+        cast_to_tuple: bool = kwargs.pop("cast_to_tuple", True)
 
         with cnx.cursor(buffered=True) as cursor:
             cursor.execute(query)
             values: list[tuple] = cursor.fetchall()
             columns: tuple[str] = cursor.column_names
-            return Response[TFlavour](model=model, response_values=values, columns=columns, flavour=flavour, select=select, **kwargs).response
+            return Response[TFlavour](model=model, response_values=values, columns=columns, flavour=flavour, select=select).response(_tuple=cast_to_tuple, **kwargs)
 
     # FIXME [ ]: this method does not comply with the implemented interface
     @get_connection
